const canvas = document.getElementById('gameCanvas');
const ctx = canvas.getContext('2d');

let paddleWidth = 10;
let paddleHeight = 100;
let paddleY = (canvas.height - paddleHeight) / 2;
let aiPaddleY = (canvas.height - paddleHeight) / 2;
let ballX = canvas.width / 2;
let ballY = canvas.height / 2;
let ballRadius = 10;
let ballSpeedX = 5;
let ballSpeedY = 2;
let ballSpeedIncrease = 0.03; // Speed increase per hit
let aiPaddleSpeed = 1.5; // Maximum speed for AI paddle
let playerScore = 0;
let aiScore = 0;
let winningScore = 5;
let gameRunning = true; // Flag to control game state

document.addEventListener('mousemove', movePaddle);
document.addEventListener('keydown', handleKeyDown);

function movePaddle(event) {
  if (!gameRunning) return; // Don't move paddle if game is paused
  const mouseY = event.clientY - canvas.getBoundingClientRect().top;
  paddleY = mouseY - paddleHeight / 2;
  if (paddleY < 0) {
    paddleY = 0;
  }
  if (paddleY + paddleHeight > canvas.height) {
    paddleY = canvas.height - paddleHeight;
  }
}

function moveAIPaddle() {
  if (!gameRunning) return; // Don't move AI paddle if game is paused
  const targetY = ballY - paddleHeight / 2;
  const distanceToBall = Math.abs(aiPaddleY - targetY);

  // Calculate movement direction
  let movement = 0;
  if (aiPaddleY < targetY) {
    movement = aiPaddleSpeed;
  } else if (aiPaddleY > targetY) {
    movement = -aiPaddleSpeed;
  }

  // Adjust movement based on distance to ball, creating smoother movement
  if (distanceToBall < aiPaddleSpeed) {
    aiPaddleY = targetY;
  } else {
    aiPaddleY += movement;
  }

  // Keep AI paddle within bounds
  if (aiPaddleY < 0) {
    aiPaddleY = 0;
  }
  if (aiPaddleY + paddleHeight > canvas.height) {
    aiPaddleY = canvas.height - paddleHeight;
  }
}

function draw() {
  ctx.clearRect(0, 0, canvas.width, canvas.height);

  // Draw scores centered on top
  ctx.fillStyle = 'white';
  ctx.font = '30px Arial';
  ctx.textAlign = 'center'; // Center align text
  ctx.fillText(`Player: ${playerScore}`, canvas.width / 2, 40);
  ctx.fillText(`AI: ${aiScore}`, canvas.width / 2, 80);

    ctx.fillRect(0, paddleY, paddleWidth, paddleHeight); // Draw player paddle
    ctx.fillRect(canvas.width - paddleWidth, aiPaddleY, paddleWidth, paddleHeight); // Draw AI paddle

    ctx.beginPath();
    ctx.arc(ballX, ballY, ballRadius, 0, Math.PI * 2);
    ctx.fill();

  // Move ball only if the game is running
  if (gameRunning) {
    ballX += ballSpeedX;
    ballY += ballSpeedY;

    // Ball collision with top and bottom
    if (ballY + ballRadius >= canvas.height || ballY - ballRadius <= 0) {
      ballSpeedY = -ballSpeedY;
    }

    // Ball collision with player paddle
    if (
      ballX - ballRadius < paddleWidth &&
      ballY > paddleY &&
      ballY < paddleY + paddleHeight
    ) {
      ballSpeedX = -ballSpeedX;
      increaseBallSpeed(); // Increase speed after hitting player paddle
    }

    // Ball collision with AI paddle
    if (
      ballX + ballRadius > canvas.width - paddleWidth &&
      ballY > aiPaddleY &&
      ballY < aiPaddleY + paddleHeight
    ) {
      ballSpeedX = -ballSpeedX;
      increaseBallSpeed(); // Increase speed after hitting AI paddle
    }

    // Check if ball goes out of bounds
    if (ballX < 0) {
      aiScore++;
      resetBall();
    } else if (ballX > canvas.width) {
      playerScore++;
      aiPaddleSpeed+=(playerScore*0.65)
      resetBall();
    }

    // Check for winner
    if (playerScore >= winningScore || aiScore >= winningScore) {
      alert(`Game Over! ${playerScore >= winningScore ? 'Player' : 'AI'} wins!`);
      playerScore = 0;
      aiScore = 0;
      ballSpeedX = 5
      ballSpeedY = 2
    }

    moveAIPaddle();
  }

  // Draw control tips
  ctx.font = '16px Arial';
  ctx.fillText('Mouse to move, Space to pause', canvas.width / 2, canvas.height - 20);

  requestAnimationFrame(draw);
}

function resetBall() {
  ballX = canvas.width / 2;
  ballY = canvas.height / 2;
  // Reset ball speed only at the start of the game or after scoring
  // ballSpeedX = 5;
  // ballSpeedY = 2;
}

function increaseBallSpeed() {
  ballSpeedX *= 1 + ballSpeedIncrease;
  ballSpeedY *= 1 + ballSpeedIncrease;
}

function handleKeyDown(event) {
  if (event.code === 'Space') {
    gameRunning = !gameRunning; // Toggle game state on spacebar press
  }
}

draw(); 
