const canvas = document.getElementById('gameCanvas');
const ctx = canvas.getContext('2d');

let paddleWidth = 10;
let paddleHeight = 100;
let player1Y = (canvas.height - paddleHeight) / 2;
let player2Y = (canvas.height - paddleHeight) / 2;
let ballX = canvas.width / 2;
let ballY = canvas.height / 2;
let ballRadius = 10;
let ballSpeedX = 5;
let ballSpeedY = 2;
let ballSpeedIncrease = 0.03; // Speed increase per hit
let player1Score = 0;
let player2Score = 0;
let winningScore = 5;
let gameRunning = true; // Flag to control game state

// Key pressed states
let player1UpPressed = false;
let player1DownPressed = false;
let player2UpPressed = false;
let player2DownPressed = false;

document.addEventListener('keydown', handleKeyDown);
document.addEventListener('keyup', handleKeyUp);

function movePaddle(player, direction) {
  if (!gameRunning) return; // Don't move paddle if game is paused

  let paddleY = player === 1 ? player1Y : player2Y;
  let speed = 5; // Paddle movement speed

  if (direction === 'up' && paddleY > 0) {
    paddleY -= speed;
  } else if (direction === 'down' && paddleY + paddleHeight < canvas.height) {
    paddleY += speed;
  }

  if (player === 1) {
    player1Y = paddleY;
  } else {
    player2Y = paddleY;
  }
}

function draw() {
  ctx.clearRect(0, 0, canvas.width, canvas.height);

  // Draw scores centered on top
  ctx.fillStyle = 'white';
  ctx.font = '30px Arial';
  ctx.textAlign = 'center'; // Center align text
  ctx.fillText(`Player 1: ${player1Score}`, canvas.width / 4, 40);
  ctx.fillText(`Player 2: ${player2Score}`, canvas.width * 3 / 4, 40);

  // Draw paddles
  ctx.fillRect(0, player1Y, paddleWidth, paddleHeight); // Draw player 1 paddle
  ctx.fillRect(canvas.width - paddleWidth, player2Y, paddleWidth, paddleHeight); // Draw player 2 paddle

  // Draw ball
  ctx.beginPath();
  ctx.arc(ballX, ballY, ballRadius, 0, Math.PI * 2);
  ctx.fill();

  // Move ball only if the game is running
  if (gameRunning) {
    ballX += ballSpeedX;
    ballY += ballSpeedY;

    // Ball collision with top and bottom
    if (ballY + ballRadius >= canvas.height || ballY - ballRadius <= 0) {
      ballSpeedY = -ballSpeedY;
    }

    // Ball collision with player 1 paddle
    if (
      ballX - ballRadius < paddleWidth &&
      ballY > player1Y &&
      ballY < player1Y + paddleHeight
    ) {
      ballSpeedX = -ballSpeedX;
      increaseBallSpeed(); // Increase speed after hitting paddle
    }

    // Ball collision with player 2 paddle
    if (
      ballX + ballRadius > canvas.width - paddleWidth &&
      ballY > player2Y &&
      ballY < player2Y + paddleHeight
    ) {
      ballSpeedX = -ballSpeedX;
      increaseBallSpeed(); // Increase speed after hitting paddle
    }

    // Check if ball goes out of bounds
    if (ballX < 0) {
      player2Score++;
      resetBall();
    } else if (ballX > canvas.width) {
      player1Score++;
      resetBall();
    }

    // Check for winner
    if (player1Score >= winningScore || player2Score >= winningScore) {
      alert(`Game Over! ${player1Score >= winningScore ? 'Player 1' : 'Player 2'} wins!`);
      player1Score = 0;
      player2Score = 0;
      ballSpeedX = 5
      ballSpeedY = 2
    }
  }

  // Draw control tips
  ctx.font = '16px Arial';
  ctx.fillText('Player 1: W/S, Player 2: Up/Down (Arrow keys or I/K)', canvas.width / 2, canvas.height - 20);

  // Continuous movement based on key pressed states
  if (player1UpPressed) {
    movePaddle(1, 'up');
  }
  if (player1DownPressed) {
    movePaddle(1, 'down');
  }
  if (player2UpPressed) {
    movePaddle(2, 'up');
  }
  if (player2DownPressed) {
    movePaddle(2, 'down');
  }

  requestAnimationFrame(draw);
}

function resetBall() {
  ballX = canvas.width / 2;
  ballY = canvas.height / 2;
  // Reset ball speed only at the start of the game or after scoring
  // ballSpeedX = 5;
  // ballSpeedY = 2;
}

function increaseBallSpeed() {
  ballSpeedX *= 1 + ballSpeedIncrease;
  ballSpeedY *= 1 + ballSpeedIncrease;
}

function handleKeyDown(event) {
  if (event.code === 'Space') {
    gameRunning = !gameRunning; // Toggle game state on spacebar press
    return;
  }

  if (!gameRunning) return;

  if (event.key === 'w') {
    player1UpPressed = true;
  } else if (event.key === 's') {
    player1DownPressed = true;
  } else if (event.key === 'ArrowUp' || event.key === 'i') {
    player2UpPressed = true;
  } else if (event.key === 'ArrowDown' || event.key === 'k') {
    player2DownPressed = true;
  }
}

function handleKeyUp(event) {
  if (event.key === 'w') {
    player1UpPressed = false;
  } else if (event.key === 's') {
    player1DownPressed = false;
  } else if (event.key === 'ArrowUp' || event.key === 'i') {
    player2UpPressed = false;
  } else if (event.key === 'ArrowDown' || event.key === 'k') {
    player2DownPressed = false;
  }
}

draw();
